@@ -31,6 +31,7 @@ setGeneric("precAcquisitionNum", function(object, ...) standardGeneric("precAcqu
 setGeneric("precScanNum", function(object, ...) standardGeneric("precScanNum"))
 setGeneric("msLevel", function(object, ...) standardGeneric("msLevel"))
 setGeneric("msLevel<-", function(object, ..., value) standardGeneric("msLevel<-"))
+setGeneric("uniqueMsLevel", function(object, ...) standardGeneric("uniqueMsLevel"))
 
 setGeneric("collisionEnergy", function(object, ...) standardGeneric("collisionEnergy"))
 setGeneric("collisionEnergy<-", function(object, ..., value) standardGeneric("collisionEnergy<-"))
@@ -55,6 +56,8 @@ setGeneric("isolationWindowUpperMz<-", function(object, ..., value) standardGene
 setGeneric("productMz", function(object, ...) standardGeneric("productMz"))
 setGeneric("productMz<-", function(object, ..., value) standardGeneric("productMz<-"))
 
+setGeneric("compounds", function(object, ...) standardGeneric("compounds"))
+
 ## -------------------------------------------------------------
 ## Raw data
 ## -------------------------------------------------------------
@@ -84,6 +87,7 @@ setGeneric("peptides", function(object, ...) standardGeneric("peptides"))
 setGeneric("proteins", function(object, ...) standardGeneric("proteins"))
 setGeneric("accessions", function(object, ...) standardGeneric("accessions"))
 setGeneric("tolerance", function(object, ...) standardGeneric("tolerance"))
+setGeneric("calculateFragments", function(sequence, object, ...) standardGeneric("calculateFragments"))
 
 ## -------------------------------------------------------------
 ## Instrument
@@ -111,6 +115,13 @@ setGeneric("smooth", function(x, ...) standardGeneric("smooth")) ## stats::smoot
 setGeneric("combineFeatures", function(object, ...) standardGeneric("combineFeatures"))
 setGeneric("aggregateFeatures", function(object, ...) standardGeneric("aggregateFeatures"))
 setGeneric("impute", function(object, ...) standardGeneric("impute"))
+setGeneric("alignRt", function(x, y, ...) standardGeneric("alignRt"))
+setGeneric("quantify", function(object, ...) standardGeneric("quantify"))
+setGeneric("bin", function(x, ...) standardGeneric("bin"))
+setGeneric("compareSpectra", function(x, y, ...)
+    standardGeneric("compareSpectra"))
+setGeneric("compareChromatograms", function(x, y, ...)
+    standardGeneric("compareChromatograms"))
 
 ## -------------------------------------------------------------
 ## IO
@@ -130,8 +141,10 @@ setGeneric("filterIsolationWindow", function(object, ...) standardGeneric("filte
 setGeneric("filterMsLevel", function(object, ...) standardGeneric("filterMsLevel"))
 setGeneric("filterPolarity", function(object, ...) standardGeneric("filterPolarity"))
 setGeneric("filterPrecursorMz", function(object, ...) standardGeneric("filterPrecursorMz"))
+setGeneric("filterPrecursorCharge", function(object, ...) standardGeneric("filterPrecursorCharge"))
 setGeneric("filterProductMz", function(object, ...) standardGeneric("filterProductMz"))
 setGeneric("filterPrecursorScan", function(object, ...) standardGeneric("filterPrecursorScan"))
 setGeneric("filterRt", function(object, ...) standardGeneric("filterRt"))
 setGeneric("filterMz", function(object, ...) standardGeneric("filterMz"))
 setGeneric("filterNA", function(object, ...) standardGeneric("filterNA"))
+setGeneric("filterIntensity", function(object, ...) standardGeneric("filterIntensity"))
